@@ -30,7 +30,7 @@ class StationBTechnogenetics(StationB):
                  starting_vol: float = 650,
                  supernatant_removal_height: float = 0.2,
                  tempdeck_slot: str = '10',
-                 tempdeck_temp: float = 55,
+                 tempdeck_temp: float = 60,
                  thermomixer_incubation_time: float = 5,
                  tipracks_slots: Tuple[str, ...] = ('4', '6', '7', '8', '9'),
                  wash_1_vol: float = 680,
@@ -186,6 +186,8 @@ class StationBTechnogenetics(StationB):
         
         self.remove_supernatant(self._starting_vol)
         self.wash(self._wash_1_vol, self.wash1, self._wash_1_times, "wash 1")
+        if self.run_stage("remove wash A"):
+            self.dual_pause("Check Wash A removal")
         self.wash(self._wash_2_vol, self.wash2, self._wash_2_times, "wash 2")
         
         if self.run_stage("spin deepwell"):
